from .ip import ip

__title__: str = 'goodip'
__version__: str = '0.0.1'
__license__: str = 'MIT license'
__author__: str = 'Erfan Bafandeh'
__url__: str = 'https://github.com/Erfan-Bafandeh/goodip'
__author_email__: str = 'user.enbh@gmail.com'
__description__: str = 'you can get your ip address and get its information.'